@@ -9,11 +9,11 @@ package org.mozilla.xpcom;
 
 public interface nsIProfileMigrator extends nsISupports
 {
-  String NS_IPROFILEMIGRATOR_IID =
+  public static final String NS_IPROFILEMIGRATOR_IID =
     "{24ce8b9d-b7ff-4279-aef4-26e158f03e34}";
 
-  void _import();
+  public void import_();
 
-  void migrate(nsIProfileStartup arg1);
+  public void migrate(nsIProfileStartup arg1);
 
 }
