@@ -9,9 +9,9 @@ package org.mozilla.xpcom;
 
 public interface nsISecretDecoderRingConfig extends nsISupports
 {
-  String NS_ISECRETDECODERRINGCONFIG_IID =
+  public static final String NS_ISECRETDECODERRINGCONFIG_IID =
     "{01d8c0f0-0ccc-11d4-9fdd-000064657374}";
 
-  void setWindow(nsISupports arg1);
+  public void setWindow(nsISupports arg1);
 
 }
